@@ -1,7 +1,7 @@
 /*
  *  messagedisplayhelper.h  -  helper class to display an alarm or error message
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -63,7 +63,7 @@ public:
         QString message;          // the alarm message
         QString remainingTime;    // if advance reminder, the remaining time until the actual alarm
         QString errorEmail[4];    // if email alarm error message, the 'To' and 'Subject' contents
-        File::FileType fileType;  // if message is a file's contents, the file type
+        File::Type fileType;      // if message is a file's contents, the file type
         bool    newLine {false};  // 'message' has a newline stripped from the end
     };
 
@@ -147,7 +147,7 @@ private:
     void    clearErrorMessage(unsigned msg) const;
     void    redisplayAlarm();
 
-    static QVector<MessageDisplayHelper*> mInstanceList;  // list of existing message displays
+    static QList<MessageDisplayHelper*> mInstanceList; // list of existing message displays
     static QHash<EventId, unsigned> mErrorMessages; // error messages currently displayed, by event ID
     // Sound file playing
     static QPointer<QThread>     mAudioThread;    // container of thread to play audio file in
@@ -171,7 +171,7 @@ public:
     KAAlarm::Type       mAlarmType;
     KAEvent::SubAction  mAction;
     KAEvent::EmailId    mEmailId;                 // if email text, message's Akonadi Item ID, else -1
-    KAEvent::CmdErrType mCommandError;
+    KAEvent::CmdErr     mCommandError;
     QStringList         mErrorMsgs;
     QString             mDontShowAgain;           // non-null for don't-show-again option with error message
     int                 mAudioRepeatPause;
